Parallel processing (:mod:`erlab.parallel`)
===========================================

.. automodule:: erlab.parallel







   .. rubric:: Functions

   .. autosummary::

      is_notebook
      joblib_progress
      joblib_progress_qt
